==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Закончить текущую игру?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Пауза&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Кликните, чтобы продолжить игру.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Игра закончена!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Кликните, чтобы начать новую.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Выберите язык приложения:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Язык системы&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Заметка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Пожалуйста, перезапустите программу, чтобы изменение используемого языка вступило в силу.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Счёт Gottet</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Уровень</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Линии</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Счёт</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Кликните, чтобы начать новую игру.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новая</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Продолжить</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Счёт</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выйти</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Язык приложения...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Следующая фигура</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Уровень</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Количество удалённых линий</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Счёт</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>Клон тетриса, который я сделал для своей жены</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Программа выпущена под &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Закончить текущую игру?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Пауза&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Кликните, чтобы продолжить игру.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Игра закончена!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Кликните, чтобы начать новую.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Выберите язык приложения:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Язык системы&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Заметка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Пожалуйста, перезапустите программу, чтобы изменение используемого языка вступило в силу.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Уровень</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Линии</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Счёт</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Кликните, чтобы начать новую игру.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новая</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Счёт</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выйти</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Язык приложения...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Следующая фигура</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Уровень</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Количество удалённых линий</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Счёт</translation>
    </message>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Программа выпущена под &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
